@@ -22,8 +22,11 @@ kable = Kable({
     "client_id": 'kci_75bfe76dea214218be408fe6fa241f07',
     "client_secret": 'sk_test.jjrhHXZL.XdSSvBt22dKQdmMvjpiQ9F9v1DGtw26h',
     "environment": 'TEST',
-    "base_url": 'https://test.kableapi.com',
-    "debug": "true"
+    "base_url": 'https://test.kable.io',
+    "debug": True,
+    # "record_authentication": False,
+    # "disable_cache": True,
+    "max_queue_size": 2
 })
 
 
@@ -34,7 +37,7 @@ def authenticated():
 
 @app.route('/record')
 def recordData():
-    kable.record({"userId": "USER", "clientId": "PYTHONFLASK", "customerId": "FLASKPYTHON"})
+    kable.record({"userId": "USER", "clientId": "test_company_1"})
     return "hello world - record data"
 
 
